# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
<!-- markdownlint-disable MD024 -->

## [rf24-rs/0.3.1] - 2025-07-22

### <!-- 6 --> 📦 Dependency updates

- Migrate to napi-rs v3 by @2bndy5 in [#64](https://github.com/nRF24/rf24-rs/pull/64)
- Bump `rf24-rs` to v0.3.1 by @2bndy5 in [`70bdf19`](https://github.com/nRF24/rf24-rs/commit/70bdf197249712bab51fb59b34397598ba2fa86f)

### <!-- 8 --> 📝 Documentation

- Revise docs about `RF24::tx_delay` property. by @2bndy5 in [`e7b29c1`](https://github.com/nRF24/rf24-rs/commit/e7b29c14ac33cdebd4437ef64f89d2a340f89613)
- Use typedoc default HTML output by @2bndy5 in [#59](https://github.com/nRF24/rf24-rs/pull/59)

[rf24-rs/0.3.1]: https://github.com/nRF24/rf24-rs/compare/rf24-rs/0.3.0...rf24-rs/0.3.1

Full commit diff: [`rf24-rs/0.3.0...rf24-rs/0.3.1`][rf24-rs/0.3.1]

## [rf24-rs/0.3.0] - 2025-05-04

### <!-- 1 --> 🚀 Added

- Use concrete error type by @2bndy5 in [#42](https://github.com/nRF24/rf24-rs/pull/42)

### <!-- 10 --> 💥 Breaking Changes

- Replace `open_tx_pipe()` with `as_tx(Option<address>)` by @2bndy5 in [#41](https://github.com/nRF24/rf24-rs/pull/41)

### <!-- 6 --> 📦 Dependency updates

- Update defmt requirement from 0.3.10 to 1.0.1 in the cargo group by @dependabot[bot] in [#31](https://github.com/nRF24/rf24-rs/pull/31)
- Bump `rf24-rs` to v0.3.0 by @2bndy5 in [`abb8fda`](https://github.com/nRF24/rf24-rs/commit/abb8fdab9575ef30fa3445067aca11f21f07dfbb)

### <!-- 9 --> 🗨️ Changed

- Regenerate change logs by @2bndy5 in [`581751a`](https://github.com/nRF24/rf24-rs/commit/581751af27d074797b4749572f05e9f8b3548e21)
- Remove `_` prefix from private members by @2bndy5 in [`39d8287`](https://github.com/nRF24/rf24-rs/commit/39d8287461777bbf9d8a1c1a92636b46b29669d0)

[rf24-rs/0.3.0]: https://github.com/nRF24/rf24-rs/compare/rf24-rs/0.2.1...rf24-rs/0.3.0

Full commit diff: [`rf24-rs/0.2.1...rf24-rs/0.3.0`][rf24-rs/0.3.0]

## [rf24-rs/0.2.1] - 2025-04-06

### <!-- 6 --> 📦 Dependency updates

- Bump `rf24-rs` to v0.2.1 by @2bndy5 in [`f266b96`](https://github.com/nRF24/rf24-rs/commit/f266b9695f1c492cce1ea7720a6df4fde298c338)

### <!-- 7 -->🚦 Tests

- Improve ``rf24-rs`` tests by @2bndy5 in [#26](https://github.com/nRF24/rf24-rs/pull/26)

### <!-- 8 --> 📝 Documentation

- Various doc updates by @2bndy5 in [#22](https://github.com/nRF24/rf24-rs/pull/22)

### <!-- 9 --> 🗨️ Changed

- Improve readability in `rf24-rs` sources by @2bndy5 in [`f468315`](https://github.com/nRF24/rf24-rs/commit/f4683153d72bd67b0a7707a3a922a0d03b852164)

[rf24-rs/0.2.1]: https://github.com/nRF24/rf24-rs/compare/rf24-rs/0.2.0...rf24-rs/0.2.1

Full commit diff: [`rf24-rs/0.2.0...rf24-rs/0.2.1`][rf24-rs/0.2.1]

## [rf24-rs/0.2.0] - 2025-03-11

### <!-- 10 --> 💥 Breaking Changes

- Rename EsbConfig to RadioConfig by @2bndy5 in [#19](https://github.com/nRF24/rf24-rs/pull/19)

### <!-- 6 --> 📦 Dependency updates

- Bump `rf24-rs` to v0.2.0 by @2bndy5 in [`5ce9ac4`](https://github.com/nRF24/rf24-rs/commit/5ce9ac456ec1e1bb00613e433ec8636919c58495)

[rf24-rs/0.2.0]: https://github.com/nRF24/rf24-rs/compare/rf24-rs/0.1.2...rf24-rs/0.2.0

Full commit diff: [`rf24-rs/0.1.2...rf24-rs/0.2.0`][rf24-rs/0.2.0]

## [rf24-rs/0.1.2] - 2025-03-09

### <!-- 6 --> 📦 Dependency updates

- Bump `rf24-rs` to v0.1.2 by @2bndy5 in [`81dd350`](https://github.com/nRF24/rf24-rs/commit/81dd350634880a4a76f3817e0e85d8099490fb37)

### <!-- 9 --> 🗨️ Changed

- Reassess min supported rust version by @2bndy5 in [`a9ca278`](https://github.com/nRF24/rf24-rs/commit/a9ca278b3ed38a682bba54bbf32de2b874ae9097)

[rf24-rs/0.1.2]: https://github.com/nRF24/rf24-rs/compare/rf24-rs/0.1.1...rf24-rs/0.1.2

Full commit diff: [`rf24-rs/0.1.1...rf24-rs/0.1.2`][rf24-rs/0.1.2]

## [rf24-rs/0.1.1] - 2025-03-09

### <!-- 1 --> 🚀 Added

- Implement nRF24L01 driver by @2bndy5 in [#1](https://github.com/nRF24/rf24-rs/pull/1)

### <!-- 6 --> 📦 Dependency updates

- Bump `rf24-rs` to v0.1.1 by @2bndy5 in [`8ca278b`](https://github.com/nRF24/rf24-rs/commit/8ca278bbbff72514c8c84001bbd3480d4ba7d1d9)

### <!-- 9 --> 🗨️ Changed

- Prepare release CI by @2bndy5 in [#14](https://github.com/nRF24/rf24-rs/pull/14)

[rf24-rs/0.1.1]: https://github.com/nRF24/rf24-rs/compare/rf24-rs/0.1.0...rf24-rs/0.1.1

Full commit diff: [`rf24-rs/0.1.0...rf24-rs/0.1.1`][rf24-rs/0.1.1]

<!-- generated by git-cliff -->
